==> cdktf-cdktf-provider-google-0.6.1.tar.gz: package/lib/data-google-pubsub-topic.d.ts <==
import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
/**
 * @stability stable
 */
export interface DataGooglePubsubTopicConfig extends cdktf.TerraformMetaArguments {
    /**
     * Name of the topic.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/google/d/pubsub_topic#name DataGooglePubsubTopic#name}
     *
     * @stability stable
     */
    readonly name: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/google/d/pubsub_topic#project DataGooglePubsubTopic#project}.
     *
     * @stability stable
     */
    readonly project?: string;
}
/**
 * @stability stable
 */
export declare class DataGooglePubsubTopicMessageStoragePolicy extends cdktf.ComplexComputedList {
    /**
     * @stability stable
     */
    get allowedPersistenceRegions(): string[];
}
/**
 * @stability stable
 */
export declare class DataGooglePubsubTopicSchemaSettings extends cdktf.ComplexComputedList {
    /**
     * @stability stable
     */
    get encoding(): string;
    /**
     * @stability stable
     */
    get schema(): string;
}
/**
 * Represents a {@link https://www.terraform.io/docs/providers/google/d/pubsub_topic google_pubsub_topic}.
 *
 * @stability stable
 */
export declare class DataGooglePubsubTopic extends cdktf.TerraformDataSource {
    /**
     * @stability stable
     */
    static readonly tfResourceType: string;
    /**
     * Create a new {@link https://www.terraform.io/docs/providers/google/d/pubsub_topic google_pubsub_topic} Data Source.
     *
     * @param scope The scope in which to define this construct.
     * @param id The scoped construct ID.
     * @stability stable
     */
    constructor(scope: Construct, id: string, config: DataGooglePubsubTopicConfig);
    /**
     * @stability stable
     */
    get id(): string;
    /**
     * @stability stable
     */
    get kmsKeyName(): string;
    /**
     * @stability stable
     */
    labels(key: string): string | cdktf.IResolvable;
    /**
     * @stability stable
     */
    messageStoragePolicy(index: string): DataGooglePubsubTopicMessageStoragePolicy;
    private _name?;
    /**
     * @stability stable
     */
    get name(): string;
    /**
     * @stability stable
     */
    set name(value: string);
    /**
     * @stability stable
     */
    get nameInput(): string | undefined;
    private _project?;
    /**
     * @stability stable
     */
    get project(): string;
    /**
     * @stability stable
     */
    set project(value: string);
    /**
     * @stability stable
     */
    resetProject(): void;
    /**
     * @stability stable
     */
    get projectInput(): string | undefined;
    /**
     * @stability stable
     */
    schemaSettings(index: string): DataGooglePubsubTopicSchemaSettings;
    /**
     * @stability stable
     */
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
}

==> cdktf-cdktf-provider-google-0.6.39.tar.gz: package/lib/data-google-pubsub-topic.d.ts <==
import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
export interface DataGooglePubsubTopicConfig extends cdktf.TerraformMetaArguments {
    /**
    * Name of the topic.
    *
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/google/d/pubsub_topic#name DataGooglePubsubTopic#name}
    */
    readonly name: string;
    /**
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/google/d/pubsub_topic#project DataGooglePubsubTopic#project}
    */
    readonly project?: string;
}
export declare class DataGooglePubsubTopicMessageStoragePolicy extends cdktf.ComplexComputedList {
    get allowedPersistenceRegions(): string[];
}
export declare class DataGooglePubsubTopicSchemaSettings extends cdktf.ComplexComputedList {
    get encoding(): string;
    get schema(): string;
}
/**
* Represents a {@link https://www.terraform.io/docs/providers/google/d/pubsub_topic google_pubsub_topic}
*/
export declare class DataGooglePubsubTopic extends cdktf.TerraformDataSource {
    static readonly tfResourceType: string;
    /**
    * Create a new {@link https://www.terraform.io/docs/providers/google/d/pubsub_topic google_pubsub_topic} Data Source
    *
    * @param scope The scope in which to define this construct
    * @param id The scoped construct ID. Must be unique amongst siblings in the same scope
    * @param options DataGooglePubsubTopicConfig
    */
    constructor(scope: Construct, id: string, config: DataGooglePubsubTopicConfig);
    get id(): string;
    get kmsKeyName(): string;
    labels(key: string): string | cdktf.IResolvable;
    messageStoragePolicy(index: string): DataGooglePubsubTopicMessageStoragePolicy;
    private _name?;
    get name(): string;
    set name(value: string);
    get nameInput(): string | undefined;
    private _project?;
    get project(): string;
    set project(value: string);
    resetProject(): void;
    get projectInput(): string | undefined;
    schemaSettings(index: string): DataGooglePubsubTopicSchemaSettings;
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
}
